==> seedsui-react-5.7.93.tgz: package/lib/TreePicker/Menu/utils/expandKeyword.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import clearClass from "./clearClass";
import getPredecessorDOM from "./getPredecessorDOM";

// 展开关键字
function expandKeyword(_ref) {
  var rootRef = _ref.rootRef,
    keyword = _ref.keyword,
    list = _ref.list;
  if (!(rootRef !== null && rootRef !== void 0 && rootRef.current) || !list || !list.length || keyword === null || keyword === undefined) {
    return;
  }

  // 取消所有展开项
  clearClass({
    rootRef: rootRef,
    classNames: ['expand']
  });

  // 如果清空, 则只需要取消所有展开项即可
  if (keyword === '') {
    return;
  }

  // 获取所有需要选中展开项
  var ids = [];
  var needExpands = null;
  function loop(children) {
    var _iterator = _createForOfIteratorHelper(children),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _item$name;
        var item = _step.value;
        if ((item === null || item === void 0 ? void 0 : (_item$name = item.name) === null || _item$name === void 0 ? void 0 : _item$name.indexOf(keyword)) !== -1) {
          ids.push(item.id);
        }
        if (Array.isArray(item.children) && item.children.length) {
          loop(item.children);
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
  loop(list);
  needExpands = getPredecessorDOM({
    rootRef: rootRef,
    ids: ids,
    list: list
  });

  // 选中dom
  if (needExpands && needExpands.length) {
    for (var i = 0, needExpand; needExpand = needExpands[i++];) {
      needExpand.classList.add('expand');
    }
  }
}
export default expandKeyword;

==> seedsui-react-5.8.44.tgz: package/lib/TreePicker/Menu/utils/expandKeyword.js <==
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import clearClass from "./clearClass";
import getPredecessorDOM from "./getPredecessorDOM";

// 展开关键字
function expandKeyword(_ref) {
  var rootRef = _ref.rootRef,
    keyword = _ref.keyword,
    list = _ref.list;
  if (!(rootRef !== null && rootRef !== void 0 && rootRef.current) || !list || !list.length || keyword === null || keyword === undefined) {
    return;
  }

  // 取消所有展开项
  clearClass({
    rootRef: rootRef,
    classNames: ['expand']
  });

  // 如果清空, 则只需要取消所有展开项即可
  if (keyword === '') {
    return;
  }

  // 获取所有需要选中展开项
  var ids = [];
  var needExpands = null;
  function loop(children) {
    var _iterator = _createForOfIteratorHelper(children),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _item$name;
        var item = _step.value;
        if ((item === null || item === void 0 || (_item$name = item.name) === null || _item$name === void 0 ? void 0 : _item$name.indexOf(keyword)) !== -1) {
          ids.push(item.id);
        }
        if (Array.isArray(item.children) && item.children.length) {
          loop(item.children);
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
  loop(list);
  needExpands = getPredecessorDOM({
    rootRef: rootRef,
    ids: ids,
    list: list
  });

  // 选中dom
  if (needExpands && needExpands.length) {
    for (var i = 0, needExpand; needExpand = needExpands[i++];) {
      needExpand.classList.add('expand');
    }
  }
}
export default expandKeyword;
